==> corefm-2.8.0.tar.gz: corefm-v2.8.0/ui/contextmenu.cpp <==
/*
	*
	* This file is a part of CoreFM.
	* A file manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/


#include "corefm.hpp"
#include "folderview.hpp"
#include "propertiesw.hpp"

static bool isArchive( QString path ) {

	QStringList archiveMimes;
	archiveMimes << "application/vnd.ms-cab-compressed" << "application/x-7z-compressed" << "application/x-7z-compressed-tar" << "application/x-ace";
	archiveMimes << "application/x-alz" << "application/x-ar" << "application/x-arj" << "application/x-bzip" << "application/x-bzip2";
	archiveMimes << "application/x-bzip-compressed-tar" << "application/x-cbr" << "application/x-cbz" << "application/x-cd-image";
	archiveMimes << "application/x-compress" << "application/x-compressed-tar" << "application/x-cpio" << "application/x-deb" << "application/x-ear";
	archiveMimes << "application/x-gzip" << "application/x-java-archive" << "application/x-lha" << "application/x-lzip";
	archiveMimes << "application/x-lzip-compressed-tar" << "application/x-lzma" << "application/x-lzma-compressed-tar" << "application/x-lzop";
	archiveMimes << "application/x-lzop-compressed-tar" << "application/x-ms-dos-executable" << "application/x-rar" << "application/x-rpm";
	archiveMimes << "application/x-rzip" << "application/x-stuffit" << "application/x-tar" << "application/x-tarz" << "application/x-war";
	archiveMimes << "application/x-xz" << "application/x-xz-compressed-tar" << "application/x-zoo" << "application/zip";

	return archiveMimes.contains( mimeDb.mimeTypeForFile( path ).name() );
}

void CoreFM::contextMenu( const QPoint & ) {

	QMenu *menu = new QMenu( currentView() );
	menu->setAttribute( Qt::WA_DeleteOnClose );

	QStringList selectedList;

	selectedList = currentView()->selection();

	if ( selectedList.isEmpty() ) {

		// Create a new file/directory
		QMenu *createNewMenu = new QMenu( "Create New" );
		createNewMenu->setIcon( QIcon::fromTheme( "archive-insert" ) );

		createNewMenu->addAction( newFolderAct );
		createNewMenu->addAction( newFileAct );

		// Special actions
		QMenu *specialMenu = new QMenu( "Specials" );
        specialMenu->addAction( treeWriteAct );

		// File/directory sorting
		QMenu *sortMenu = new QMenu( "&Sort by" );
		sortMenu->setIcon( QIcon::fromTheme( "view-sort-ascending" ) );

		sortMenu->addAction( sortNameAct );
		sortMenu->addAction( sortSizeAct );
		sortMenu->addAction( sortDateAct );
		sortMenu->addSeparator();
		sortMenu->addAction( sortOrderAct );

		menu->addMenu( createNewMenu );
		menu->addMenu( specialMenu );
		menu->addSeparator();

		menu->addAction( termAct );
		menu->addSeparator();

		menu->addAction( pasteAct );
		menu->addSeparator();

		menu->addAction( refreshAct );
		menu->addSeparator();

		menu->addAction( selectAllAct );
		menu->addSeparator();

		menu->addSeparator();
		menu->addMenu( sortMenu );

		menu->addSeparator();
		menu->addAction( propsAct );
	}

	else if ( selectedList.count() == 1 ) {

		menu->addAction( openAct );

		QFileInfo fInfo( selectedList[ 0 ] );
		QString file = fInfo.absoluteFilePath();
		QMimeType mType = CPrime::FileUtils::mimeType( file );

		if ( fInfo.isDir() ) {
			menu->addAction( newWindowAct );
			menu->addSeparator();
		}

		menu->addMenu( openWithMenu() );

		// Special actions
		QMenu *specialMenu = new QMenu( "Specials" );
		if ( fInfo.isDir() ) {
			specialMenu->addAction( treeWriteAct );
            specialMenu->addAction( batchRenameAct );
			menu->addMenu( specialMenu );
		}

        if ( fInfo.isFile()) {
            specialMenu->addAction( metadataAct );
            specialMenu->addAction( batchRenameAct );
            menu->addMenu( specialMenu );
        }
		menu->addSeparator();

		if ( fInfo.isDir() ) {
			menu->addAction( termAct );
			menu->addSeparator();
		}

		menu->addAction( cutAct );
		menu->addAction( copyAct );
		menu->addSeparator();

		menu->addAction( renameAct );

		menu->addSeparator();
		if ( not isArchive( selectedList.value( 0 ) ) )
			menu->addAction( compressAct );

		else
			menu->addAction( extractAct );

		menu->addSeparator();

		menu->addAction( trashAct );
		menu->addAction( deleteAct );

		menu->addSeparator();
		menu->addAction( propsAct );
	}

	else {
		menu->addAction( cutAct );
		menu->addAction( copyAct );
		menu->addSeparator();

		menu->addAction( trashAct );
		menu->addAction( deleteAct );

		menu->addSeparator();
		menu->addAction( propsAct );
	}

	menu->exec( QCursor::pos() );
};

QMenu* CoreFM::openWithMenu() {

	QMenu *openMenu = new QMenu( tr( "Open with" ), this );
	QStringList selectedItems = currentView()->selection();

	// Select action
	QAction *selectAppAct = new QAction( tr( "Select..." ), openMenu );
	connect( selectAppAct, SIGNAL( triggered() ), this, SLOT( selectApp() ) );

	// Load default applications for current mime
	AppsList apps = mimeHandler->appsForMimeType( mimeDb.mimeTypeForFile( selectedItems.value( 0 ) ) );

	// Create actions for opening
	QList<QAction *> defaultApps;

	Q_FOREACH( CoreDesktopFile app, apps ) {

		QString name = app.name();
		QIcon icon = CPrime::ThemeFunc::getAppIcon( app.desktopName() );

		// Create action
		QAction *action = new QAction( icon, name, openMenu );
        action->setData( QVariant::fromValue<CoreDesktopFile>( app ) );
		defaultApps.append( action );

		// TODO: icon and connect
		connect( action, SIGNAL( triggered() ), SLOT( openInApp() ) );

		// Add action to menu
		openMenu->addAction( action );
	}

	// Add open action to menu
	openMenu->addSeparator();
	openMenu->addAction( selectAppAct );
	return openMenu;
};

==> corefm-4.1.0.tar.gz: corefm-v4.1.0/ui/contextmenu.cpp <==
/*
	*
	* This file is a part of CoreFM.
	* A file manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/


#include "corefm.h"
#include "folderview.hpp"
#include "propertiesw.hpp"

void corefm::contextMenu( const QPoint & ) {

	QMenu *menu = new QMenu( currentView() );
	menu->setAttribute( Qt::WA_DeleteOnClose );

	QStringList selectedList;

	selectedList = currentView()->selection();

	if ( selectedList.isEmpty() ) {

		// Create a new file/directory
		QMenu *createNewMenu = new QMenu( "Create New" );
		createNewMenu->setIcon( QIcon::fromTheme( "archive-insert" ) );

		createNewMenu->addAction( newFolderAct );
		createNewMenu->addAction( newFileAct );

		// Special actions
		QMenu *specialMenu = new QMenu( "Specials" );
        specialMenu->addAction( treeWriteAct );

		// File/directory sorting
		QMenu *sortMenu = new QMenu( "&Sort by" );
		sortMenu->setIcon( QIcon::fromTheme( "view-sort-ascending" ) );

		sortMenu->addAction( sortNameAct );
		sortMenu->addAction( sortSizeAct );
		sortMenu->addAction( sortDateAct );
		sortMenu->addSeparator();
		sortMenu->addAction( sortOrderAct );

		menu->addMenu( createNewMenu );
		menu->addMenu( specialMenu );
		menu->addSeparator();

		menu->addAction( termAct );
		menu->addSeparator();

		menu->addAction( pasteAct );
		menu->addSeparator();

		menu->addAction( refreshAct );
		menu->addSeparator();

		menu->addAction( selectAllAct );
		menu->addSeparator();

		menu->addSeparator();
		menu->addMenu( sortMenu );

		menu->addSeparator();
		menu->addAction( propsAct );
	}

	else if ( selectedList.count() == 1 ) {

		menu->addAction( openAct );

		QFileInfo fInfo( selectedList[ 0 ] );

		if ( fInfo.isDir() ) {
			menu->addAction( newWindowAct );
			menu->addAction( openInSplitAct );
			menu->addSeparator();
		}

		menu->addMenu( openWithMenu() );

		// Special actions
		QMenu *specialMenu = new QMenu( "Specials" );
		if ( fInfo.isDir() ) {
			specialMenu->addAction( treeWriteAct );
            specialMenu->addAction( batchRenameAct );
			menu->addMenu( specialMenu );
		}

        if ( fInfo.isFile()) {
            specialMenu->addAction( metadataAct );
            specialMenu->addAction( batchRenameAct );
            menu->addMenu( specialMenu );
        }
		menu->addSeparator();

		if ( fInfo.isDir() ) {
			menu->addAction( termAct );
			menu->addSeparator();
		}

		menu->addAction( cutAct );
		menu->addAction( copyAct );
		menu->addSeparator();
		menu->addAction( renameAct );
		menu->addSeparator();
		menu->addAction( trashAct );
		menu->addAction( deleteAct );
		menu->addSeparator();
		menu->addAction( propsAct );
	}

	else {
		menu->addMenu( openWithMenu() );
		menu->addSeparator();
		menu->addAction( cutAct );
		menu->addAction( copyAct );
		menu->addSeparator();
		menu->addAction( trashAct );
		menu->addAction( deleteAct );
		menu->addSeparator();
		menu->addAction( propsAct );
	}

	menu->exec( QCursor::pos() );
};

QMenu* corefm::openWithMenu() {

	QMenu *openMenu = new QMenu( tr( "Open with" ), this );
	QStringList selectedItems = currentView()->selection();

	// Select action
	QAction *selectAppAct = new QAction( tr( "Select..." ), openMenu );
	connect( selectAppAct, SIGNAL( triggered() ), this, SLOT( selectApp() ) );

	// Load default applications for current mime
	AppsList apps = mimeHandler->appsForMimeType( mimeDb.mimeTypeForFile( selectedItems.value( 0 ) ) );

	// Create actions for opening
	QList<QAction *> defaultApps;

	Q_FOREACH( CoreDesktopFile app, apps ) {

		QString name = app.name();
		QIcon icon = CPrime::ThemeFunc::getAppIcon( app.desktopName() );

		// Create action
		QAction *action = new QAction( icon, name, openMenu );
        action->setData( QVariant::fromValue<CoreDesktopFile>( app ) );
		defaultApps.append( action );

		// TODO: icon and connect
		connect( action, SIGNAL( triggered() ), SLOT( openInApp() ) );

		// Add action to menu
		openMenu->addAction( action );
	}

	// Add open action to menu
	openMenu->addSeparator();
	openMenu->addAction( selectAppAct );
	return openMenu;
};
